@@ -1,13 +1,11 @@
 """
-Functions for loading data from audio files.
+Loading data from audio files.
 
 ```
 data, samplingrate = load_audio('audio/file.wav')
 ```
 Loads the whole file by trying different modules until it succeeds to load the data.
 
-`data = unwrap(data)`: fix wrapped data.
-
 ```
 data = AudioLoader('audio/file.wav', 60.0)
 ```
@@ -18,15 +16,28 @@ with open_audio_loader('audio/file.wav', 60.0) as data:
 Create an `AudioLoader` instance that loads chuncks of 60 seconds long data on demand.
 data can be used like a read-only numpy array of floats.
 
+In some wav files clipped data are folded into the available data range. With
+```
+data = unwrap(data)
+```
+such data can be unwrapped.
+
+For a demo run the module as:
+```
+python -m audioio.audioloader audiofile.wav
+```
+
+## Installation notes
+
 The built in wave module only supports a few wav file formats.
 The libsndfile library can handle many more formats and is interfaced
-by many different python packages (e.g. pysoundfile, wavefile, scikits.audiolab).
-We recommend using pysoundfile for best results:
+by many different python packages (e.g. SoundFile, wavefile, scikits.audiolab).
+We recommend using SoundFile for best results:
 
-To install pysoundfile on Linux do:
+To install SoundFile on Linux do:
 ```
 sudo apt-get install -y libsndfile1 libsndfile1-dev libffi-dev
-sudo pip install pysoundfile
+sudo pip install SoundFile
 ```
 
 mp3 and similar formats are supported by the audioread module. Install it via:
@@ -34,10 +45,8 @@ mp3 and similar formats are supported by the audioread module. Install it via:
 sudo apt-get install -y libav-tools python-audioread
 ```
 
-For a demo, run the script as:
-```
-python -m audioio.audioloader audiofile.wav
-```
+See te audioio.audiomodules module and script for further information on
+installed audio packages and instructions on how to install them.
 """
  
 import warnings
@@ -199,7 +208,7 @@ def load_wavfile(filepath, verbose=0):
 
 def load_soundfile(filepath, verbose=0):
     """
-    Load audio file using pysoundfile (based on libsndfile).
+    Load audio file using SoundFile (based on libsndfile).
 
     Documentation
     -------------
@@ -210,7 +219,7 @@ def load_soundfile(filepath, verbose=0):
     ------------
     ```
     sudo apt-get install -y libsndfile1 libsndfile1-dev libffi-dev
-    sudo pip install pysoundfile
+    sudo pip install SoundFile
     ```
 
     Parameters
@@ -549,7 +558,7 @@ class AudioLoader(object):
     data.open(filepath, 60.0)
     ```
     
-    or for a specific module, here the pysoundfile module:
+    or for a specific module, here the SoundFile module:
     ```
     data = aio.AudioLoader()
     data.open_soundfile(filepath, 60.0)
@@ -920,9 +929,9 @@ class AudioLoader(object):
                       % (self.buffer.shape[0], self.offset, self.offset+self.buffer.shape[0]))
 
             
-    # pysoundfile interface:        
+    # soundfile interface:        
     def open_soundfile(self, filepath, buffersize=10.0, backsize=0.0, verbose=0):
-        """Open audio file for reading using the pysoundfile module.
+        """Open audio file for reading using the SoundFile module.
 
         Parameters
         ----------
@@ -937,7 +946,7 @@ class AudioLoader(object):
 
         Raises
         ------
-        ImportError: The pysoundfile module is not installed
+        ImportError: The SoundFile module is not installed
         """
         self.verbose = verbose
         if self.verbose > 1:
@@ -969,14 +978,14 @@ class AudioLoader(object):
         return self
 
     def _close_soundfile(self):
-        """ Close the audio file using the pysoundfile module. """
+        """ Close the audio file using the SoundFile module. """
         if self.sf is not None:
             self.sf.close()
             self.sf = None
 
     def _update_buffer_soundfile(self, start, stop):
         """Make sure that the buffer contains the data between
-        start and stop using the pysoundfile module.
+        start and stop using the SoundFile module.
         """
         if start < self.offset or stop > self.offset + self.buffer.shape[0]:
             offset, size = self._read_indices(start, stop)
